ValidationRule

Enum ValidationRule 

#[non_exhaustive]
pub enum ValidationRule { Pattern(Regex), Length(usize), LengthRange { min: usize, max: usize, }, Checksum(ChecksumType), NumericRange { min: f64, max: f64, }, Enum(Vec<String>), All(Vec<ValidationRule>), }
Validation rule for an operator parameter.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Pattern(Regex)

Pattern matching (pre-compiled regex)



Length(usize)

Exact length



LengthRange

Min and max length

Fields

min: usize

Minimum allowed length (inclusive).

max: usize

Maximum allowed length (inclusive).



Checksum(ChecksumType)

Checksum algorithm



NumericRange

Range of numeric values

Fields

min: f64

Minimum allowed numeric value (inclusive).

max: f64

Maximum allowed numeric value (inclusive).



Enum(Vec<String>)

Value must be one of these options



All(Vec<ValidationRule>)

Composite rule (all must pass)

Implementations

Source

impl ValidationRule

pub fn validate(&self, value: &str) -> Result<()>

Validate a string value against this rule.

Errors

Returns FraiseQLError::Validation if the value fails the validation rule, or if the pattern is an invalid regex.

pub fn from_json(value: &Value) -> Result<Self>

Parse validation rules from JSON (compiled from TOML).

Errors

Returns FraiseQLError::Validation if the JSON structure does not match any known validation rule format.

Panics

Cannot panic: the internal .expect("len checked == 1") is only reached after verifying rules.len() == 1.