#[non_exhaustive]pub enum CursorValue {
Int64(i64),
Uuid(String),
}Expand description
A typed cursor value for keyset (relay) pagination.
The cursor type is determined at compile time by QueryDefinition::relay_cursor_type
and used at runtime to choose the correct SQL comparison and cursor
encoding/decoding path.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Int64(i64)
BIGINT primary key cursor (default, backward-compatible).
Uuid(String)
UUID cursor — bound as text and cast to uuid in SQL.